Download
--------

::

    pip install heflwr

⚠!!ATTENTION!!⚠
---------------
Check the `Project Homepage <https://github.com/QVQZZZ/HeFlwr>`_ for the complete README.


Quick Start
-----------

::

    import heflwr
